.TH gd 1.2  31/5/95

.SH NAME
 gd 

.SH SYNOPSIS

A graphics library for fast GIF creation

.SH DESCRIPTION
.PP

gd is a graphics library. It allows your code to quickly draw images complete
with lines, arcs, text, multiple colors, cut and paste from other images, and
flood fills, and write out the result as a .GIF file. This is particularly useful in
World Wide Web applications, where .GIF is the format used for inline
images. 

gd is not a paint program. If you are looking for a paint program, try xpaint
by David Koblas, available by anonymous FTP from ftp.netcom.com in
pub/koblas. (That package is for the X Window System; for the Mac and the
PC, paint programs are considerably easier to find.) 

gd does not provide for every possible desirable graphics operation. It is not
necessary or desirable for gd to become a kitchen-sink graphics package, but
version 1.1.1 incorporates most of the commonly requested features for a 2D
package. 

.SH Features

.B o Polygon fills 
.PP
.B o Line styling 
.PP
.B o "Brushing" of lines with a brush image 
.PP
.B o Tiling of polygon, rectangle and flood-fills 
.PP
.B o Interlaced GIFs for gradual fade-in 
.PP
.B o Macros to access image size, etc. 



.SH Gd basics - using gd

gd lets you create GIF images on the fly. To use gd in your program, include
the file gd.h, and link with the libgd.a library produced by "make libgd.a",
under Unix. You will need to adapt the makefile for your needs if you are
using a non-Unix operating system, but this is very straightforward. 

If you want to use the provided fonts, include gdfontl.h and/or gdfonts.h. You
do not need to explicitly link with gdfontl.o and gdfonts.o any longer as of
version 1.1.1. 

.B Here is a short example program. 

(For a more advanced example, see gddemo.c, included in the distribution. 
gddemo.c is NOT the same program; it demonstrates additional features!) 

/* Bring in gd library functions */
#include "gd.h"

/* Bring in standard I/O so we can output the GIF to a file */
#include <stdio.h>

int main() {
        /* Declare the image */
        gdImagePtr im;
        /* Declare an output file */
        FILE *out;
        /* Declare color indexes */
        int black;
        int white;

        /* Allocate the image: 64 pixels across by 64 pixels tall */
        im = gdImageCreate(64, 64);

        /* Allocate the color black (red, green and blue all minimum).
                Since this is the first color in a new image, it will
                be the background color. */
        black = gdImageColorAllocate(im, 0, 0, 0);      

        /* Allocate the color white (red, green and blue all maximum). */
        white = gdImageColorAllocate(im, 255, 255, 255);        
        
        /* Draw a line from the upper left to the lower right,
                using white color index. */
        gdImageLine(im, 0, 0, 63, 63, white);   

        /* Open a file for writing. "wb" means "write binary", important
                under MSDOS, harmless under Unix. */
        out = fopen("test.gif", "wb");

        /* Output the image to the disk file. */
        gdImageGif(im, out);    

        /* Close the file. */
        fclose(out);

        /* Destroy the image in memory. */
        gdImageDestroy(im);
}




When executed, this program creates an image, allocates two colors (the
first color allocated becomes the background color), draws a diagonal line
(note that 0, 0 is the upper left corner), writes the image to a GIF file, and
destroys the image. 

The above example program should give you an idea of how the package
works. gd provides many additional functions, which are listed in the
following reference chapters, complete with code snippets demonstrating
each. There is also an alphabetical index. 

.SH Webgif: a more powerful gd example

Webgif is a simple utility program to manipulate GIFs from the command
line. It is written for Unix and similar command-line systems, but should be
easily adapted for other environments. Webgif allows you to set
transparency and interlacing and output interesting information about the
GIF in question. 

.SH Author
.B Thomas Boutell, boutell@netcom.com

.SH Man page   
A few points taken from the full documentation (and  manual) which can be found  
in the file gd.html.

.SH Copyright Notes
gd 1.1.1 is copyright 1994, Quest Protein Database Center,
Cold Spring Harbor Labs. Permission granted to copy and distribute
this work provided that this notice remains intact. Credit
for the library must be given to the Quest Protein Database Center,
Cold Spring Harbor Labs, in all derived works. This does not
affect your ownership of the derived work itself, and the intent
is to assure proper credit for Quest, not to interfere with your
use of gd. If you have questions, ask. ("Derived works"
includes all programs that utilize the library. Credit must
be given in user-visible documentation.)
